<?php

namespace Litecms\GiftCard\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\GiftCard\Models\GiftCard;

class GiftCardPolicy
{

    /**
     * Determine if the given user can view the gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function view(UserPolicy $user, GiftCard $gift_card)
    {
        if ($user->canDo('gift_card.gift_card.view') && $user->isAdmin()) {
            return true;
        }

        return $gift_card->user_id == user_id() && $gift_card->user_type == user_type();
    }

    /**
     * Determine if the given user can create a gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('gift_card.gift_card.create');
    }

    /**
     * Determine if the given user can update the given gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function update(UserPolicy $user, GiftCard $gift_card)
    {
        if ($user->canDo('gift_card.gift_card.edit') && $user->isAdmin()) {
            return true;
        }

        return $gift_card->user_id == user_id() && $gift_card->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, GiftCard $gift_card)
    {
        return $gift_card->user_id == user_id() && $gift_card->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function verify(UserPolicy $user, GiftCard $gift_card)
    {
        if ($user->canDo('gift_card.gift_card.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given gift_card.
     *
     * @param UserPolicy $user
     * @param GiftCard $gift_card
     *
     * @return bool
     */
    public function approve(UserPolicy $user, GiftCard $gift_card)
    {
        if ($user->canDo('gift_card.gift_card.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
